Welcome to DDSIM's documentation!
=================================

A tool for quantum circuit simulation by the `Chair for Design Automation <https://www.cda.cit.tum.de/>`_ at the `Technical University of Munich <https://www.tum.de/>`_.
DDSIM is part of the Munich Quantum Toolkit (MQT; formerly known as JKQ and developed by the `Institute for Integrated Circuits <https://iic.jku.at/eda/>`_ at the `Johannes Kepler University Linz <https://jku.at>`_).
It builds upon `our quantum functionality representation (QFR) <https://github.com/cda-tum/qfr>`_ and `our decision diagram (DD) package <https://github.com/cda-tum/dd_package.git>`_.

The tool builds upon our `quantum functionality representation (QFR) <https://github.com/cda-tumu/qfr.git>`_ which in turns builds on our `decision diagram (DD) package <https://github.com/cda-tum/dd_package.git>`_.

For more information, on our work on quantum circuit simulation please visit `www.cda.cit.tum.de/research/quantum_simulation <https://www.cda.cit.tum.de/research/quantum_simulation>`_ or, for more information on our work on noise-aware quantum circuit simulation, please visit `www.cda.cit.tum.de/research/noise_aware_simulation <https://www.cda.cit.tum.de/research/noise_aware_simulation/>`_.

If you have any questions, feel free to contact us via quantum.cda@xcit.tum.de or by creating an `issue <https://github.com/cda-tum/ddsim/issues>`_ on GitHub.


----

.. toctree::
   :hidden:

   self

.. toctree::
   :maxdepth: 2
   :caption: User Guide
   :glob:

   Installation
   Quickstart
   Simulators
   Usage
   FAQ
   Publications

.. toctree::
   :maxdepth: 2
   :caption: Developers
   :glob:

   Contributing
   Development
   Support

.. toctree::
   :maxdepth: 1
   :caption: API Reference
   :glob:

   api/modules
   api/Cpp
